@@ -65,11 +65,14 @@ typedef struct monitor_t {
     GtkWidget      *wImgBox;
     GtkWidget      *wTitle;
     GtkWidget      *wValue;
+    GtkWidget      *wValButton;
+    GtkWidget      *wValButtonLabel;
     GtkWidget      *wImage;
     GtkWidget      *wBar;
     GtkWidget      *wButton;
     GtkWidget      *wImgButton;
     char           *onClickCmd;
+    char           *onValClickCmd;
 } monitor_t;
 
 typedef struct genmon_t {
@@ -92,8 +95,8 @@ static void ExecOnClickCmd (GtkWidget *p_wSc, void *p_pvPlugin)
     if (error) {
         char *first = g_strdup_printf (_("Could not run \"%s\""), poMonitor->onClickCmd);
         xfce_message_dialog (NULL, _("Xfce Panel"),
-                             GTK_STOCK_DIALOG_ERROR, first, error->message,
-                             GTK_STOCK_CLOSE, GTK_RESPONSE_OK, NULL);
+                             "dialog-error", first, error->message,
+                             "gtk-close", GTK_RESPONSE_OK, NULL);
         g_error_free (error);
         g_free (first);
     }
@@ -101,13 +104,30 @@ static void ExecOnClickCmd (GtkWidget *p_wSc, void *p_pvPlugin)
 }
 
 /**************************************************************/
+static void ExecOnValClickCmd (GtkWidget *p_wSc, void *p_pvPlugin)
+/* Execute the onClick Command */
+{
+    struct genmon_t *poPlugin = (genmon_t *) p_pvPlugin;
+    struct monitor_t *poMonitor = &(poPlugin->oMonitor);
+    GError *error = NULL;
 
+    xfce_spawn_command_line_on_screen( gdk_screen_get_default(), poMonitor->onValClickCmd, 0, 0, &error );
+    if (error) {
+        char *first = g_strdup_printf (_("Could not run \"%s\""), poMonitor->onValClickCmd);
+        xfce_message_dialog (NULL, _("Xfce Panel"),
+                             "dialog-error", first, error->message,
+                             "gtk-close", GTK_RESPONSE_OK, NULL);
+        g_error_free (error);
+        g_free (first);
+    }
+
+}
+
+/**************************************************************/
 static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
  /* Launch the command, get its output and display it in the panel-docked
     text field */
 {
-    static GtkTooltips *s_poToolTips = 0;
-
     struct param_t *poConf = &(p_poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(p_poPlugin->oMonitor);
     char  *acToolTips;
@@ -115,9 +135,6 @@ static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
     char  *end;
     int    newVersion=0;
 
-    if (!s_poToolTips)
-        s_poToolTips = gtk_tooltips_new ();
-
     g_free (p_poPlugin->acValue);
     if (poConf->acCmd[0])
         p_poPlugin->acValue = genmon_SpawnCmd (poConf->acCmd, 1);
@@ -128,7 +145,7 @@ static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
     if (!p_poPlugin->acValue)
         p_poPlugin->acValue = g_strdup ("XXX");
 
-    /* Test if the result is an Image or a Text */
+    /* Test if the result is an Image */
     begin=strstr(p_poPlugin->acValue, "<img>");
     end=strstr(p_poPlugin->acValue, "</img>");
     if (begin && end && begin < end)
@@ -176,14 +193,40 @@ static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
         /* Get the text */
         char *buf = g_strndup (begin + 5, end - begin - 5);
         gtk_label_set_markup (GTK_LABEL (poMonitor->wValue), buf);
-        g_free (buf);
+        
+        /* Test if the result has a clickable Value (button) */
+        begin=strstr(p_poPlugin->acValue, "<txtclick>");
+        end=strstr(p_poPlugin->acValue, "</txtclick>");
+        if (begin && end && begin < end)
+        {
+            /* Add the text to the button label too*/
+            gtk_label_set_markup (GTK_LABEL (poMonitor->wValButtonLabel), buf);
 
-        gtk_widget_show (poMonitor->wValue);
+            /* Get the command path */
+            g_free (poMonitor->onValClickCmd);
+            poMonitor->onValClickCmd = g_strndup (begin + 10, end - begin - 10);
+            
+            gtk_widget_show (poMonitor->wValButton);
+            gtk_widget_show (poMonitor->wValButtonLabel);
+            gtk_widget_hide (poMonitor->wValue);
+            
+        }
+        else
+        {
+            gtk_widget_hide (poMonitor->wValButton);
+            gtk_widget_hide (poMonitor->wValButtonLabel);
+            gtk_widget_show (poMonitor->wValue);
+        }
 
         newVersion=1;
+        g_free (buf);
     }
     else
+    {
         gtk_widget_hide (poMonitor->wValue);
+        gtk_widget_hide (poMonitor->wValButton);
+        gtk_widget_hide (poMonitor->wValButtonLabel);
+    }
 
     /* Test if the result is a Bar */
     begin=strstr(p_poPlugin->acValue, "<bar>");
@@ -223,14 +266,13 @@ static int DisplayCmdOutput (struct genmon_t *p_poPlugin)
     if (begin && end && begin < end)
         acToolTips = g_strndup (begin + 6, end - begin - 6);
     else
-        acToolTips = g_strdup_printf (acToolTips, "%s\n"
+        acToolTips = g_strdup_printf ("%s\n"
             "----------------\n"
             "%s\n"
             "Period (s): %d", poConf->acTitle, poConf->acCmd,
             poConf->iPeriod_ms / 1000);
 
-    gtk_tooltips_set_tip (s_poToolTips, GTK_WIDGET (poMonitor->wEventBox),
-        acToolTips, 0);
+    gtk_widget_set_tooltip_text (GTK_WIDGET (poMonitor->wEventBox),acToolTips);
     g_free (acToolTips);
 
     return (0);
@@ -269,8 +311,14 @@ static genmon_t *genmon_create_control (XfcePanelPlugin *plugin)
     struct param_t *poConf;
     struct monitor_t *poMonitor;
     GtkOrientation orientation = xfce_panel_plugin_get_orientation (plugin);
-    int size = xfce_panel_plugin_get_size (plugin);
+    GtkSettings *settings;
+    gchar *default_font;
 
+    #if GTK_CHECK_VERSION (3, 16, 0)
+        GtkCssProvider *css_provider;
+        gchar * css;
+    #endif
+    
     poPlugin = g_new (genmon_t, 1);
     memset (poPlugin, 0, sizeof (genmon_t));
     poConf = &(poPlugin->oConf.oParam);
@@ -286,7 +334,16 @@ static genmon_t *genmon_create_control (XfcePanelPlugin *plugin)
     poConf->iPeriod_ms = 30 * 1000;
     poPlugin->iTimerId = 0;
 
-    poConf->acFont = g_strdup ("(default)");
+    // PangoFontDescription needs a font and we can't use "(Default)" anymore.
+    // Use GtkSettings to get the current default font and use that, or set default to "Sans 10"
+    settings = gtk_settings_get_default();
+    if (g_object_class_find_property(G_OBJECT_GET_CLASS(settings), "gtk-font-name"))
+    {
+        g_object_get(settings, "gtk-font-name", &default_font, NULL);
+        poConf->acFont = g_strdup (default_font); 
+    }
+    else
+        poConf->acFont = g_strdup ("Sans 10");
 
     poMonitor->wEventBox = gtk_event_box_new ();
     gtk_event_box_set_visible_window (
@@ -295,10 +352,10 @@ static genmon_t *genmon_create_control (XfcePanelPlugin *plugin)
 
     xfce_panel_plugin_add_action_widget (plugin, poMonitor->wEventBox);
 
-    poMonitor->wBox = xfce_hvbox_new (orientation, FALSE, 0);
+    poMonitor->wBox = gtk_box_new (orientation, 0);
     gtk_widget_show (poMonitor->wBox);
     gtk_container_set_border_width (GTK_CONTAINER
-        (poMonitor->wBox), BORDER);
+        (poMonitor->wBox), 0);
     gtk_container_add (GTK_CONTAINER (poMonitor->wEventBox),
         poMonitor->wBox);
 
@@ -309,7 +366,7 @@ static genmon_t *genmon_create_control (XfcePanelPlugin *plugin)
         GTK_WIDGET (poMonitor->wTitle), FALSE, FALSE, 0);
 
     /* Create a Box to put image and text */
-    poMonitor->wImgBox = xfce_hvbox_new (orientation, FALSE, 0);
+    poMonitor->wImgBox = gtk_box_new (orientation, 0);
     gtk_widget_show (poMonitor->wImgBox);
     gtk_container_set_border_width (GTK_CONTAINER
         (poMonitor->wImgBox), 0);
@@ -338,14 +395,63 @@ static genmon_t *genmon_create_control (XfcePanelPlugin *plugin)
     gtk_box_pack_start (GTK_BOX (poMonitor->wImgBox),
         GTK_WIDGET (poMonitor->wValue), TRUE, FALSE, 0);
 
+    /* Add Value Button */
+    poMonitor->wValButton = xfce_create_panel_button ();
+    xfce_panel_plugin_add_action_widget (plugin, poMonitor->wValButton);
+    gtk_box_pack_start (GTK_BOX (poMonitor->wImgBox),
+        GTK_WIDGET (poMonitor->wValButton), TRUE, FALSE, 0);
+
+    /* Add Value Button Label */
+    poMonitor->wValButtonLabel = gtk_label_new ("");
+    gtk_container_add (GTK_CONTAINER (poMonitor->wValButton), poMonitor->wValButtonLabel);
+    gtk_container_set_border_width (GTK_CONTAINER (poMonitor->wValButton), 0);
+
     /* Add Bar */
     poMonitor->wBar = gtk_progress_bar_new();
     gtk_box_pack_start (GTK_BOX (poMonitor->wBox),
         GTK_WIDGET (poMonitor->wBar), FALSE, FALSE, 0);
     if (orientation == GTK_ORIENTATION_HORIZONTAL)
-        gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(poMonitor->wBar), GTK_PROGRESS_BOTTOM_TO_TOP);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBar), GTK_ORIENTATION_VERTICAL);
     else
-        gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(poMonitor->wBar), GTK_PROGRESS_LEFT_TO_RIGHT);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBar), GTK_ORIENTATION_HORIZONTAL);
+
+    /* make widget padding consistent */
+    #if GTK_CHECK_VERSION (3, 16, 0)
+    #if GTK_CHECK_VERSION (3, 20, 0)
+        css = g_strdup_printf("* {padding: 1; margin: 1; }");
+    #else
+        css = g_strdup_printf("* {padding: 1; margin: 1; }");
+    #endif
+    #endif
+
+    css_provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wTitle))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wImage))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);  
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wButton))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wValue))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);    
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wValButton))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);                
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wBar))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);  
+    g_free(css);
+    g_free(default_font);
 
     return poPlugin;
 }/* genmon_create_control() */
@@ -375,6 +481,49 @@ static int SetMonitorFont (void *p_pvPlugin)
     struct genmon_t *poPlugin = (genmon_t *) p_pvPlugin;
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
     struct param_t *poConf = &(poPlugin->oConf.oParam);
+    
+#if GTK_CHECK_VERSION (3, 16, 0)
+    GtkCssProvider *css_provider;
+    gchar * css;
+#if GTK_CHECK_VERSION (3, 20, 0)
+  PangoFontDescription *font;
+  font = pango_font_description_from_string(poConf->acFont);
+  if (G_LIKELY (font))
+  {
+    css = g_strdup_printf("label { font-family: %s; font-size: %dpx; font-style: %s; font-weight: %s }",
+                          pango_font_description_get_family (font),
+                          pango_font_description_get_size (font) / PANGO_SCALE,
+                          (pango_font_description_get_style(font) == PANGO_STYLE_ITALIC ||
+                           pango_font_description_get_style(font) == PANGO_STYLE_OBLIQUE) ? "italic" : "normal",
+                          (pango_font_description_get_weight(font) >= PANGO_WEIGHT_BOLD) ? "bold" : "normal");
+    pango_font_description_free (font);
+  }
+  else
+    css = g_strdup_printf("label { font: %s; }", 
+#else
+    css = g_strdup_printf(".label { font: %s; }", 
+#endif
+                                    poConf->acFont);                        
+    /* Setup Gtk style */
+    DBG("css: %s",css);
+    
+    css_provider = gtk_css_provider_new ();
+    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wTitle))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wValue))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    gtk_style_context_add_provider (
+        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (poMonitor->wValButtonLabel))),
+        GTK_STYLE_PROVIDER (css_provider),
+        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    g_free(css);
+#else
+    
     PangoFontDescription *poFont;
 
     if (!strcmp (poConf->acFont, "(default)")) /* Default font */
@@ -382,9 +531,16 @@ static int SetMonitorFont (void *p_pvPlugin)
     poFont = pango_font_description_from_string (poConf->acFont);
     if (!poFont)
         return (-1);
-    gtk_widget_modify_font (poMonitor->wTitle, poFont);
-    gtk_widget_modify_font (poMonitor->wValue, poFont);
-    return (0);
+        
+    gtk_widget_override_font (poMonitor->wTitle, poFont);
+    gtk_widget_override_font (poMonitor->wValue, poFont);
+    gtk_widget_override_font (poMonitor->wValButton, poFont);
+    
+    pango_font_description_free (poFont);
+    
+#endif
+
+return (0);
 }/* SetMonitorFont() */
 
 /**************************************************************/
@@ -567,17 +723,33 @@ static void UpdateConf (void *p_pvPlugin)
 
 /**************************************************************/
 
-static void About (GtkWidget *w, void *unused)
-/* Called back when the About button in clicked */
-{
-    xfce_dialog_show_info (NULL,
-        _("Cyclically spawns a script/program, captures its output "
-        "and displays the resulting string in the panel\n\n"
-        "(c) 2004 Roger Seguin <roger_seguin@msn.com>\n"
-        "(c) 2006 Julien Devemy <jujucece@gmail.com>"),
-        _("%s %s - Generic Monitor"),
-        PACKAGE, VERSION);
-}/* About() */
+static void About (XfcePanelPlugin *plugin)
+{ 
+  GdkPixbuf *icon;
+
+  const gchar *auth[] =
+    {
+      "Roger Seguin <roger_seguin@msn.com>",
+      "Julien Devemy <jujucece@gmail.com>",
+      "Tony Paulic <tony.paulic@gmail.com>",
+      NULL
+    };
+
+  icon = xfce_panel_pixbuf_from_source ("utilities-system-monitor", NULL, 32);
+  gtk_show_about_dialog (NULL,
+                         "logo",         icon,
+                         "license",      xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
+                         "version",      VERSION,
+                         "program-name", PACKAGE,
+                         "comments",     _("Cyclically spawns a script/program, captures its output and displays the resulting string in the panel"),
+                         "website",      "http://goodies.xfce.org/projects/panel-plugins/xfce4-genmon-plugin",
+                         "copyright",    _("Copyright \xc2\xa9 2004 Roger Seguin\nCopyright \xc2\xa9 2006 Julien Devemy\nCopyright \xc2\xa9 2016 Tony Paulic\n"),
+                         "authors",      auth,
+                         NULL);
+
+  if (icon)
+    g_object_unref (G_OBJECT (icon));
+}
 
 /**************************************************************/
 
@@ -589,16 +761,15 @@ static void ChooseFont (GtkWidget *p_wPB, void *p_pvPlugin)
     const char     *pcFont;
     int             iResponse;
 
-    wDialog = gtk_font_selection_dialog_new (_("Font Selection"));
+    wDialog = gtk_font_chooser_dialog_new (_("Font Selection"),
+        GTK_WINDOW(gtk_widget_get_toplevel(p_wPB)));
     gtk_window_set_transient_for (GTK_WINDOW (wDialog),
         GTK_WINDOW (poPlugin->oConf.wTopLevel));
     if (strcmp (poConf->acFont, "(default)")) /* Default font */
-        gtk_font_selection_dialog_set_font_name (GTK_FONT_SELECTION_DIALOG
-            (wDialog), poConf->acFont);
+        gtk_font_chooser_set_font (GTK_FONT_CHOOSER (wDialog), poConf->acFont);
     iResponse = gtk_dialog_run (GTK_DIALOG (wDialog));
     if (iResponse == GTK_RESPONSE_OK) {
-        pcFont = gtk_font_selection_dialog_get_font_name
-            (GTK_FONT_SELECTION_DIALOG (wDialog));
+        pcFont = gtk_font_chooser_get_font (GTK_FONT_CHOOSER (wDialog));
         if (pcFont) {
             g_free (poConf->acFont);
             poConf->acFont = g_strdup (pcFont);
@@ -636,9 +807,8 @@ static void genmon_create_options (XfcePanelPlugin *plugin,
 
     dlg = xfce_titled_dialog_new_with_buttons (_("Configuration"),
         GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (plugin))),
-        GTK_DIALOG_DESTROY_WITH_PARENT |
-        GTK_DIALOG_NO_SEPARATOR,
-        GTK_STOCK_CLOSE, GTK_RESPONSE_OK,
+        GTK_DIALOG_DESTROY_WITH_PARENT,
+        "gtk-close", GTK_RESPONSE_OK,
         NULL);
 
     g_signal_connect (dlg, "response", G_CALLBACK (genmon_dialog_response),
@@ -646,11 +816,11 @@ static void genmon_create_options (XfcePanelPlugin *plugin,
 
     xfce_titled_dialog_set_subtitle (XFCE_TITLED_DIALOG (dlg), _("Generic Monitor"));
 
-    vbox = gtk_vbox_new(FALSE, BORDER);
-    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER - 2);
+    vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, BORDER + 6);
+    gtk_container_set_border_width (GTK_CONTAINER (vbox), BORDER + 4);
     gtk_widget_show(vbox);
-    gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox), vbox,
-    TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX (gtk_dialog_get_content_area(GTK_DIALOG(dlg))), vbox, 
+        TRUE, TRUE, 0);
 
     poPlugin->oConf.wTopLevel = dlg;
 
@@ -693,16 +863,15 @@ static void genmon_set_orientation (XfcePanelPlugin *plugin,
 /* Plugin API */
 /* Invoked when the panel changes orientation */
 {
-    struct param_t *poConf = &(poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
 
-    xfce_hvbox_set_orientation (XFCE_HVBOX (poMonitor->wBox), p_iOrientation);
-    xfce_hvbox_set_orientation (XFCE_HVBOX (poMonitor->wImgBox), p_iOrientation);
+    gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBox), p_iOrientation);
+    gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wImgBox), p_iOrientation);
 
     if (p_iOrientation == GTK_ORIENTATION_HORIZONTAL)
-        gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(poMonitor->wBar), GTK_PROGRESS_BOTTOM_TO_TOP);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBar), GTK_ORIENTATION_VERTICAL);
     else
-        gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(poMonitor->wBar), GTK_PROGRESS_LEFT_TO_RIGHT);
+        gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBar), GTK_ORIENTATION_HORIZONTAL);
 
     SetMonitorFont (poPlugin);
 
@@ -729,6 +898,32 @@ static gboolean genmon_set_size (XfcePanelPlugin *plugin, int size, genmon_t *po
     return TRUE;
 }/* genmon_set_size() */
 
+/**************************************************************/
+// call: xfce4-panel --plugin-event=genmon-X:refresh:bool:true
+//    where genmon-X is the genmon widget id (e.g. genmon-7)
+
+static gboolean genmon_remote_event (XfcePanelPlugin *plugin,
+                                    const gchar *name,
+                                    const GValue *value,
+                                    genmon_t *genmon)
+{
+    g_return_val_if_fail (value == NULL || G_IS_VALUE (value), FALSE);
+    if (strcmp (name, "refresh") == 0)
+        {
+        if (value != NULL
+            && G_VALUE_HOLDS_BOOLEAN (value)
+            && g_value_get_boolean (value))
+            {
+            /* update the display */
+            DisplayCmdOutput (genmon);
+            }
+        return TRUE;
+        }
+
+    return FALSE;
+}/* genmon_remote_event() */
+
+
 /**************************************************************/
 
 static void genmon_construct (XfcePanelPlugin *plugin)
@@ -757,14 +952,20 @@ static void genmon_construct (XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "size-changed", G_CALLBACK (genmon_set_size), genmon);
 
     xfce_panel_plugin_menu_show_about (plugin);
-    g_signal_connect (plugin, "about", G_CALLBACK (About), genmon);
-
+    
+    g_signal_connect (plugin, "about", G_CALLBACK (About), plugin);
+    
     xfce_panel_plugin_menu_show_configure (plugin);
     g_signal_connect (plugin, "configure-plugin",
         G_CALLBACK (genmon_create_options), genmon);
 
+    g_signal_connect (plugin, "remote-event", G_CALLBACK (genmon_remote_event), genmon);
+
     g_signal_connect (G_OBJECT (genmon->oMonitor.wButton), "clicked",
         G_CALLBACK (ExecOnClickCmd), genmon);
+
+    g_signal_connect (G_OBJECT (genmon->oMonitor.wValButton), "clicked",
+        G_CALLBACK (ExecOnValClickCmd), genmon);        
 }
 
 XFCE_PANEL_PLUGIN_REGISTER (genmon_construct)
